"""This is a library for help with Modded Cell Machine level codes."""

_plugins = [
    "V1",
    "V2",
    # "V3",
]

from . import base74, level
